<!-- dreamtim documentation master file, created by
sphinx-quickstart on Tue Apr  5 13:37:30 2022.
You can adapt this file completely to your liking, but it should at least
contain the root `toctree` directive. -->
# Welcome to dreamtim’s documentation!

# Contents:


* [dreamtim package](dreamtim.md)


    * [Submodules](dreamtim.md#submodules)


    * [dreamtim.calculator module](dreamtim.md#module-dreamtim.calculator)


    * [dreamtim.statistical_tools module](dreamtim.md#module-dreamtim.statistical_tools)


    * [Module contents](dreamtim.md#module-dreamtim)


# Indices and tables


* [Index](genindex.md)


* [Module Index](py-modindex.md)


* [Search Page](search.md)
